# Only tested on Salt 3005.1
# Based on the following recipes:
# https://podman.io/getting-started/installation#building-from-scratch
# https://gitlab.com/rhcontainerbot/podman/-/tree/debian/debian
# https://github.com/containers/podman/issues/4580
# https://github.com/containers/crun

{% set SRC = "/root/source" %}

Update packages:
  pkg.uptodate

Build dependencies:
  pkg.installed:
    - names:
        - git
        - golang-go
        - go-md2man
        - iptables
        - pkg-config
        - btrfs-progs
        - uidmap
        - libglib2.0-dev
        - libsystemd-dev
        - libassuan-dev
        - libbtrfs-dev
        - libc6-dev
        - libdevmapper-dev
        - libapparmor-dev
        - libgpgme-dev
        - libseccomp2
        - libseccomp-dev
        - libgpg-error-dev
        - libprotobuf-c-dev
        - libprotobuf-dev
        - libselinux1-dev
        # - runc # we will build it from scratch
        # - crun # we will build it from scratch
        - libcap-dev
        - gcc
        - build-essential
        - pkgconf
        - libtool
        - libcap-dev
        - libyajl-dev
        - libgcrypt20-dev
        - autoconf
        - python3
        - automake

/etc/containers:
  file.directory

/etc/containers/registries.conf:
  file.managed:
    - source: https://raw.githubusercontent.com/projectatomic/registries/master/registries.fedora
    - source_hash: cab27fcbb6c5abdb8dedad6cd49725b0

/etc/containers/policy.json:
  file.managed:
    - source: https://raw.githubusercontent.com/containers/skopeo/master/default-policy.json
    - source_hash: c01eb6950f03419e09d4fc88cb42ff6f

Conmon repo:
  git.latest:
    - name: https://github.com/containers/conmon
    - target: {{ SRC }}/src/github.com/containers/conmon
    - force_reset: true
    - rev: 'v2.1.4'  # or 'HEAD'

Conmon build:
  cmd.run:
    - name: 'make && make install.bin install.crio install.podman'
    - cwd: {{ SRC }}/src/github.com/containers/conmon
    - failhard: true
    - onchanges:
        - git: Conmon repo

# Runc repo:
#   git.latest:
#     - name: https://github.com/opencontainers/runc
#     - target: {{ SRC }}/src/github.com/opencontainers/runc
#     - force_reset: true
#     - rev: 'v1.1.4'  # or 'HEAD'

# Runc build:
#   cmd.run:
#     - name: 'make BUILDTAGS="apparmor selinux seccomp" && cp runc /usr/local/bin/'
#     - cwd: {{ SRC }}/src/github.com/opencontainers/runc
#     - failhard: true
#     - env:
#         - GOPATH: {{ SRC }}
#         - GOCACHE: {{ SRC }}/cache
#     - onchanges:
#         - git: Runc repo

Crun repo:
  git.latest:
    - name: https://github.com/containers/crun
    - target: {{ SRC }}/src/github.com/containers/crun
    - force_reset: true
    - rev: '1.6'  # or 'HEAD'

Crun build:
  cmd.run:
    - name: './autogen.sh && ./configure && make && make install'
    - cwd: {{ SRC }}/src/github.com/containers/crun
    - failhard: true
    - onchanges:
        - git: Crun repo

Plugins repo:
  git.latest:
    - name: https://github.com/containernetworking/plugins
    - target: {{ SRC }}/src/github.com/containernetworking/plugins
    - force_reset: true
    - rev: 'v1.1.1'  # or 'HEAD'

Plugins build:
  file.directory:
    - name: /usr/local/lib/cni
  cmd.run:
    - name: './build_linux.sh && cp bin/* /usr/local/lib/cni/'
    - cwd: {{ SRC }}/src/github.com/containernetworking/plugins
    - failhard: true
    - env:
        - GOPATH: {{ SRC }}
        - GOCACHE: {{ SRC }}/cache
    - onchanges:
        - git: Plugins repo

Podman repo:
  git.latest:
    - name: https://github.com/containers/libpod
    - target: {{ SRC }}/src/github.com/containers/libpod
    - force_reset: true
    - rev: 'v4.3.0'  # or 'HEAD'

{% set BUILDTAGS = "apparmor selinux seccomp systemd" %}

Podman build:
  cmd.run:
    - name: 'make BUILDTAGS="{{ BUILDTAGS }}" && make install PREFIX=/usr/local'
    - cwd: {{ SRC }}/src/github.com/containers/libpod
    - failhard: true
    - env:
        - GOPATH: {{ SRC }}
        - GOCACHE: {{ SRC }}/cache
    - onchanges:
        - git: Podman repo

/etc/systemd/system/podman.service:
  file.symlink:
    - target: /usr/local/lib/systemd/system/podman.service

/etc/systemd/system/podman.socket:
  file.symlink:
    - target: /usr/local/lib/systemd/system/podman.socket

Podman service:
  service.running:
    - name: podman.socket
    - enable: true
    - watch:
        - cmd: Podman build
